
This is a backend module for python-anyconfig to load and dump configuration
data configobj supports.

- Author: Satoru SATOH <ssato@redhat.com>
- License: MIT

SEE ALSO:

- python-anyconfig: https://pypi.python.org/pypi/anyconfig
- configobj: http://www.voidspace.org.uk/python/configobj.html

.. - Download:

..   - PyPI: https://pypi.python.org/pypi/anyconfig-configobj-backend
  - Copr RPM repos: https://copr.fedoraproject.org/coprs/ssato/python-anyconfig/

.. vim:sw=2:ts=2:et:
